﻿using System;
using System.Drawing;

using Foundation;
using UIKit;
using Syncfusion.SfChart.iOS;
using CoreGraphics;

namespace ChartSample
{
	public partial class ChartSampleViewController : UIViewController
	{
		static bool UserInterfaceIdiomIsPhone {
			get { return UIDevice.CurrentDevice.UserInterfaceIdiom == UIUserInterfaceIdiom.Phone; }
		}

		public ChartSampleViewController (IntPtr handle) : base (handle)
		{
		}

		public override void DidReceiveMemoryWarning ()
		{
			base.DidReceiveMemoryWarning ();
		}

		#region View lifecycle

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			SFChart chart                         	= new SFChart ();
			chart.EdgeInsets 					  	= new UIEdgeInsets (25,10,10,20);
			chart.Frame                           	= this.View.Frame;
			SFDateTimeAxis primaryAxis     	      	= new SFDateTimeAxis ();
			primaryAxis.Interval 				  	= NSObject.FromObject(4);
			primaryAxis.PlotOffset 				  	= 10;
			primaryAxis.ShowMajorGridLines 		  	= false;
			primaryAxis.IntervalType 			  	= SFChartDateTimeIntervalType.Days;
			NSDateFormatter formatter 			  	= new NSDateFormatter ();
			formatter.DateFormat 				  	= "dd MMM";
			primaryAxis.LabelStyle.LabelFormatter 	= formatter;
			chart.PrimaryAxis                     	= primaryAxis;
			SFNumericalAxis secondaryAxis 		  	= new SFNumericalAxis ();
			secondaryAxis.AxisLineStyle.LineWidth 	= 0;
			secondaryAxis.MajorTickStyle.LineWidth 	= 0;
			chart.SecondaryAxis                   	= secondaryAxis;
			chart.Legend.Visible 			      	= true ;
			chart.Legend.DockPosition 				= SFChartLegendPosition.Bottom;

			ChartDataModel dataModel              	= new ChartDataModel ();
			chart.DataSource                      	= dataModel as SFChartDataSource;

			this.View.AddSubview (chart);
		}

		public override void ViewWillAppear (bool animated)
		{
			base.ViewWillAppear (animated);
		}

		public override void ViewDidAppear (bool animated)
		{
			base.ViewDidAppear (animated);
		}

		public override void ViewWillDisappear (bool animated)
		{
			base.ViewWillDisappear (animated);
		}

		public override void ViewDidDisappear (bool animated)
		{
			base.ViewDidDisappear (animated);
		}

		#endregion
	}
		
	public class ChartDataModel : SFChartDataSource
	{
		NSMutableArray Data1;
		NSMutableArray Data2;
		NSMutableArray Data3;

		public ChartDataModel ()
		{
			Data1 = new NSMutableArray ();
			Data2 = new NSMutableArray ();
			Data3 = new NSMutableArray ();

			Data1.Add(new SFChartDataPoint (GetDateValue(new DateTime(2014,8,2)),NSObject.FromObject ( 50)));
			Data1.Add(new SFChartDataPoint (GetDateValue(new DateTime(2014,8,15)), NSObject.FromObject (20)));
			Data1.Add(new SFChartDataPoint (GetDateValue(new DateTime(2014,8,20)), NSObject.FromObject (30)));
			Data1.Add(new SFChartDataPoint (GetDateValue(new DateTime(2014,9,2)), NSObject.FromObject (40)));

			Data2.Add(new SFChartDataPoint (GetDateValue(new DateTime(2014,8,5)), NSObject.FromObject (30)));
			Data2.Add(new SFChartDataPoint (GetDateValue(new DateTime(2014,8,18)), NSObject.FromObject (10)));
			Data2.Add(new SFChartDataPoint (GetDateValue(new DateTime(2014,9,2)), NSObject.FromObject (40)));

			Data3.Add(new SFChartDataPoint (GetDateValue(new DateTime(2014,8,2)), NSObject.FromObject (30)));
			Data3.Add(new SFChartDataPoint (GetDateValue(new DateTime(2014,9,2)), NSObject.FromObject (40)));

		}

		public NSDate GetDateValue(DateTime date)
		{
			NSCalendar cal 			= new NSCalendar (NSCalendarType.Gregorian);
			NSDateComponents comp 	= new NSDateComponents ();
			comp.Day 				= date.Day;
			comp.Month 				= date.Month;
			comp.Year 				= date.Year;
			comp.Hour 				= date.Hour;
			comp.Minute 			= date.Minute;
			comp.Second 			= date.Second;
			return cal.DateFromComponents (comp);
		}
			
		//[Export ("numberOfSeriesInChart:")]
		public override nint NumberOfSeriesInChart (SFChart chart)
		{
			return 3; 
		}

		//[Export ("chart:seriesAtIndex:")]
		public override SFSeries GetSeries (SFChart chart, nint index)
		{
			SFLineSeries series 		 	= new SFLineSeries ();
			series.LegendIcon 			 	= SFChartLegendIcon.SeriesType;
			series.DataMarker.ShowMarker 	= true;
			series.DataMarker.MarkerType 	= SFChartDataMarkerType.Ellipse;
			series.DataMarker.MarkerHeight 	= 10;
			series.DataMarker.MarkerWidth	= 10;

			if (index == 0) {
				series.Label 					= new NSString ("Series1");
				series.Color 					= UIColor.Blue;
				series.DataMarker.MarkerColor 	= UIColor.Blue;
			} else if (index == 1) {
				series.Label 					= new NSString ("Series2");
				series.Color 					= UIColor.Red;
				series.DataMarker.MarkerColor 	= UIColor.Red;
			} else if (index == 2) {
				series.Label 					= new NSString ("Series3");
				series.Color 					= UIColor.Green;
				series.DataMarker.MarkerColor 	= UIColor.Green;
			} 

			return series;
		}

		//[Export ("chart:dataPointAtIndex:forSeriesAtIndex:")]
		public override SFChartDataPoint GetDataPoint (SFChart chart, nint index, nint seriesIndex)
		{
			if (seriesIndex == 0)
				return Data1.GetItem<SFChartDataPoint> ((nuint)index);
			else if (seriesIndex == 1)
				return Data2.GetItem<SFChartDataPoint> ((nuint)index);
			else 
				return Data3.GetItem<SFChartDataPoint> ((nuint)index);
			
		}

		//[Export ("chart:numberOfDataPointsForSeriesAtIndex:")]
		public override nint GetNumberOfDataPoints (SFChart chart, nint index)
		{
			if(index == 0)
				return (int)Data1.Count;
			else if(index ==1)
				return (int)Data2.Count;
			else 
				return (int)Data3.Count;
			
		}
	}
}
